# pylint: disable=no-member,wrong-import-position,too-many-lines,no-name-in-module
from typing import Dict

# artifact
import instill.protogen.artifact.artifact.v1alpha.artifact_pb2 as artifact_interface
import instill.protogen.artifact.artifact.v1alpha.artifact_public_service_pb2_grpc as artifact_service
import instill.protogen.artifact.artifact.v1alpha.chunk_pb2 as chunk_interface

# common
import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck
from instill.clients.base import Client, RequestFactory
from instill.clients.constant import DEFAULT_INSTANCE
from instill.clients.instance import InstillInstance
from instill.configuration import global_config
from instill.utils.error_handler import grpc_handler


class ArtifactClient(Client):
    def __init__(self, async_enabled: bool) -> None:
        self.hosts: Dict[str, InstillInstance] = {}
        if DEFAULT_INSTANCE in global_config.hosts:
            self.instance = DEFAULT_INSTANCE
        elif len(global_config.hosts) == 0:
            self.instance = ""
        else:
            self.instance = list(global_config.hosts.keys())[0]

        if global_config.hosts is not None:
            for instance, config in global_config.hosts.items():
                self.hosts[instance] = InstillInstance(
                    artifact_service.ArtifactPublicServiceStub,
                    url=config.url,
                    token=config.token,
                    secure=config.secure,
                    async_enabled=async_enabled,
                )

    @property
    def hosts(self):
        return self._hosts

    @hosts.setter
    def hosts(self, hosts: Dict[str, InstillInstance]):
        self._hosts = hosts

    @property
    def instance(self):
        return self._instance

    @instance.setter
    def instance(self, instance: str):
        self._instance = instance

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: str):
        self._metadata = metadata

    def liveness(
        self,
        async_enabled: bool = False,
    ) -> artifact_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.Liveness,
                request=artifact_interface.LivenessRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.Liveness,
            request=artifact_interface.LivenessRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    def readiness(
        self,
        async_enabled: bool = False,
    ) -> artifact_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.Readiness,
                request=artifact_interface.ReadinessRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.Readiness,
            request=artifact_interface.ReadinessRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def create_knowledge_base(
        self,
        namespace_id: str,
        name: str,
        description: str,
        tags: list[str],
        async_enabled: bool = False,
    ) -> artifact_interface.CreateKnowledgeBaseResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.CreateKnowledgeBase,
                request=artifact_interface.CreateKnowledgeBaseRequest(
                    namespace_id=namespace_id,
                    name=name,
                    description=description,
                    tags=tags,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.CreateKnowledgeBase,
            request=artifact_interface.CreateKnowledgeBaseRequest(
                namespace_id=namespace_id,
                name=name,
                description=description,
                tags=tags,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_knowledge_bases(
        self,
        namespace_id: str,
        async_enabled: bool = False,
    ) -> artifact_interface.ListKnowledgeBasesResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListKnowledgeBases,
                request=artifact_interface.ListKnowledgeBasesRequest(
                    namespace_id=namespace_id,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListKnowledgeBases,
            request=artifact_interface.ListKnowledgeBasesRequest(
                namespace_id=namespace_id,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def update_knowledge_base(
        self,
        kb_id: str,
        description: str,
        tags: str,
        namespace_id: str,
        async_enabled: bool = False,
    ) -> artifact_interface.UpdateKnowledgeBaseResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UpdateKnowledgeBase,
                request=artifact_interface.UpdateKnowledgeBaseRequest(
                    kb_id=kb_id,
                    description=description,
                    tags=tags,
                    namespace_id=namespace_id,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UpdateKnowledgeBase,
            request=artifact_interface.UpdateKnowledgeBaseRequest(
                kb_id=kb_id,
                description=description,
                tags=tags,
                namespace_id=namespace_id,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_knowledge_base(
        self,
        namespace_id: str,
        kb_id: str,
        async_enabled: bool = False,
    ) -> artifact_interface.DeleteKnowledgeBaseResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeleteKnowledgeBase,
                request=artifact_interface.DeleteKnowledgeBaseRequest(
                    namespace_id=namespace_id,
                    kb_id=kb_id,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteKnowledgeBase,
            request=artifact_interface.DeleteKnowledgeBaseRequest(
                namespace_id=namespace_id,
                kb_id=kb_id,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def upload_knowledge_base_file(
        self,
        namespace_id: str,
        kb_id: str,
        file: artifact_interface.File,
        async_enabled: bool = False,
    ) -> artifact_interface.UploadKnowledgeBaseFileResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UploadKnowledgeBaseFile,
                request=artifact_interface.UploadKnowledgeBaseFileRequest(
                    namespace_id=namespace_id,
                    kb_id=kb_id,
                    file=file,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UploadKnowledgeBaseFile,
            request=artifact_interface.UploadKnowledgeBaseFileRequest(
                namespace_id=namespace_id,
                kb_id=kb_id,
                file=file,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_knowledge_base_file(
        self,
        file_uid: str,
        async_enabled: bool = False,
    ) -> artifact_interface.DeleteKnowledgeBaseFileResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeleteKnowledgeBaseFile,
                request=artifact_interface.DeleteKnowledgeBaseFileRequest(
                    file_uid=file_uid,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteKnowledgeBaseFile,
            request=artifact_interface.DeleteKnowledgeBaseFileRequest(
                file_uid=file_uid,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def process_knowledge_base_files(
        self,
        file_uids: list[str],
        async_enabled: bool = False,
    ) -> artifact_interface.ProcessKnowledgeBaseFilesResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ProcessKnowledgeBaseFiles,
                request=artifact_interface.ProcessKnowledgeBaseFilesRequest(
                    file_uids=file_uids,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ProcessKnowledgeBaseFiles,
            request=artifact_interface.ProcessKnowledgeBaseFilesRequest(
                file_uids=file_uids,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_knowledge_base_files(
        self,
        namespace_id: str,
        kb_id: str,
        files_filter: artifact_interface.ListKnowledgeBaseFilesFilter,
        page_size: int = 100,
        page_token: str = "",
        async_enabled: bool = False,
    ) -> artifact_interface.ListKnowledgeBaseFilesResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListKnowledgeBaseFiles,
                request=artifact_interface.ListKnowledgeBaseFilesRequest(
                    namespace_id=namespace_id,
                    kb_id=kb_id,
                    filter=files_filter,
                    page_size=page_size,
                    page_token=page_token,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListKnowledgeBaseFiles,
            request=artifact_interface.ListKnowledgeBaseFilesRequest(
                namespace_id=namespace_id,
                kb_id=kb_id,
                filter=files_filter,
                page_size=page_size,
                page_token=page_token,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_chunks(
        self,
        namespace_id: str,
        kb_id: str,
        file_uid: str,
        async_enabled: bool = False,
    ) -> chunk_interface.ListChunksResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListChunks,
                request=chunk_interface.ListChunksRequest(
                    namespace_id=namespace_id,
                    kb_id=kb_id,
                    file_uid=file_uid,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListChunks,
            request=chunk_interface.ListChunksRequest(
                namespace_id=namespace_id,
                kb_id=kb_id,
                file_uid=file_uid,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_source_file(
        self,
        namespace_id: str,
        kb_id: str,
        file_uid: str,
        async_enabled: bool = False,
    ) -> chunk_interface.GetSourceFileResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetSourceFile,
                request=chunk_interface.GetSourceFileRequest(
                    namespace_id=namespace_id,
                    kb_id=kb_id,
                    file_uid=file_uid,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetSourceFile,
            request=chunk_interface.GetSourceFileRequest(
                namespace_id=namespace_id,
                kb_id=kb_id,
                file_uid=file_uid,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def update_chunk(
        self,
        chunk_uid: str,
        retrievable: bool,
        async_enabled: bool = False,
    ) -> chunk_interface.UpdateChunkResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UpdateChunk,
                request=chunk_interface.UpdateChunkRequest(
                    chunk_uid=chunk_uid,
                    retrievable=retrievable,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UpdateChunk,
            request=chunk_interface.UpdateChunkRequest(
                chunk_uid=chunk_uid,
                retrievable=retrievable,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def similarity_chunks_search(
        self,
        namespace_id: str,
        kb_id: str,
        text_prompt: str,
        topk: int,
        async_enabled: bool = False,
    ) -> chunk_interface.SimilarityChunksSearchResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.SimilarityChunksSearch,
                request=chunk_interface.SimilarityChunksSearchRequest(
                    namespace_id=namespace_id,
                    kb_id=kb_id,
                    text_prompt=text_prompt,
                    topk=topk,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.SimilarityChunksSearch,
            request=chunk_interface.SimilarityChunksSearchRequest(
                namespace_id=namespace_id,
                kb_id=kb_id,
                text_prompt=text_prompt,
                topk=topk,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ore/mgmt/v1beta/mgmt.proto\x12\x10\x63ore.mgmt.v1beta\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x96\x01\n\x0fLivenessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"|\n\x10LivenessResponse\x12h\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x04\xe2\x41\x01\x03R\x13healthCheckResponse\"\x97\x01\n\x10ReadinessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"}\n\x11ReadinessResponse\x12h\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x04\xe2\x41\x01\x03R\x13healthCheckResponse\"-\n\nPermission\x12\x1f\n\x08\x63\x61n_edit\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x07\x63\x61nEdit\"\xd3\x03\n\x0bUserProfile\x12,\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64isplayName\x88\x01\x01\x12\x1b\n\x03\x62io\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\x03\x62io\x88\x01\x01\x12!\n\x06\x61vatar\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x61vatar\x88\x01\x01\x12,\n\x0cpublic_email\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x0bpublicEmail\x88\x01\x01\x12,\n\x0c\x63ompany_name\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x0b\x63ompanyName\x88\x01\x01\x12m\n\x14social_profile_links\x18\x06 \x03(\x0b\x32\x35.core.mgmt.v1beta.UserProfile.SocialProfileLinksEntryB\x04\xe2\x41\x01\x01R\x12socialProfileLinks\x1a\x45\n\x17SocialProfileLinksEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_display_nameB\x06\n\x04_bioB\t\n\x07_avatarB\x0f\n\r_public_emailB\x0f\n\r_company_name\"\xa4\x03\n\x13OrganizationProfile\x12,\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64isplayName\x88\x01\x01\x12\x1b\n\x03\x62io\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\x03\x62io\x88\x01\x01\x12!\n\x06\x61vatar\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x61vatar\x88\x01\x01\x12,\n\x0cpublic_email\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x0bpublicEmail\x88\x01\x01\x12u\n\x14social_profile_links\x18\x05 \x03(\x0b\x32=.core.mgmt.v1beta.OrganizationProfile.SocialProfileLinksEntryB\x04\xe2\x41\x01\x01R\x12socialProfileLinks\x1a\x45\n\x17SocialProfileLinksEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_display_nameB\x06\n\x04_bioB\t\n\x07_avatarB\x0f\n\r_public_email\"\x96\x05\n\x11\x41uthenticatedUser\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x1b\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x05H\x00R\x03uid\x88\x01\x01\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\x12\x41\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x1a\n\x05\x65mail\x18\x07 \x01(\tB\x04\xe2\x41\x01\x02R\x05\x65mail\x12%\n\x0b\x63ustomer_id\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\ncustomerId\x12\x1d\n\x04role\x18\x0c \x01(\tB\x04\xe2\x41\x01\x01H\x01R\x04role\x88\x01\x01\x12=\n\x17newsletter_subscription\x18\r \x01(\x08\x42\x04\xe2\x41\x01\x02R\x16newsletterSubscription\x12,\n\x0c\x63ookie_token\x18\x0e \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x0b\x63ookieToken\x88\x01\x01\x12U\n\x11onboarding_status\x18\x11 \x01(\x0e\x32\".core.mgmt.v1beta.OnboardingStatusB\x04\xe2\x41\x01\x01R\x10onboardingStatus\x12=\n\x07profile\x18\x12 \x01(\x0b\x32\x1d.core.mgmt.v1beta.UserProfileB\x04\xe2\x41\x01\x03R\x07profile:\'\xea\x41$\n\"api.instill.tech/AuthenticatedUserB\x06\n\x04_uidB\x07\n\x05_roleB\x0f\n\r_cookie_token\"\x90\x01\n\x05Owner\x12\x32\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x04\xe2\x41\x01\x03H\x00R\x04user\x12J\n\x0corganization\x18\x02 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03H\x00R\x0corganizationB\x07\n\x05owner\"\xd9\x02\n\x04User\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x1b\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03H\x00R\x03uid\x88\x01\x01\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x41\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x37\n\x07profile\x18\x0b \x01(\x0b\x32\x1d.core.mgmt.v1beta.UserProfileR\x07profile:=\xea\x41:\n\x15\x61pi.instill.tech/User\x12\x0fusers/{user.id}\x12\x10users/{user.uid}B\x06\n\x04_uid\"\xf4\x01\n\x15ListUsersAdminRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x35\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\x8d\x01\n\x16ListUsersAdminResponse\x12,\n\x05users\x18\x01 \x03(\x0b\x32\x16.core.mgmt.v1beta.UserR\x05users\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"n\n\x13GetUserAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"B\n\x14GetUserAdminResponse\x12*\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserR\x04user\"s\n\x16LookUpUserAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12\x19\n\x08user_uid\x18\x03 \x01(\tR\x07userUidB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"E\n\x17LookUpUserAdminResponse\x12*\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserR\x04user\"\xe4\x01\n\x1dListOrganizationsAdminRequest\x12 \n\tpage_size\x18\x01 \x01(\x05H\x00R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x02 \x01(\tH\x01R\tpageToken\x88\x01\x01\x12/\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x02R\x04view\x88\x01\x01\x12\x1b\n\x06\x66ilter\x18\x04 \x01(\tH\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\xad\x01\n\x1eListOrganizationsAdminResponse\x12\x44\n\rorganizations\x18\x01 \x03(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\rorganizations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x86\x01\n\x1bGetOrganizationAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12\'\n\x0forganization_id\x18\x03 \x01(\tR\x0eorganizationIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"b\n\x1cGetOrganizationAdminResponse\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\"\x8b\x01\n\x1eLookUpOrganizationAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12)\n\x10organization_uid\x18\x03 \x01(\tR\x0forganizationUidB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"e\n\x1fLookUpOrganizationAdminResponse\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\"\xef\x01\n\x10ListUsersRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x35\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\x9a\x01\n\x11ListUsersResponse\x12\x32\n\x05users\x18\x01 \x03(\x0b\x32\x16.core.mgmt.v1beta.UserB\x04\xe2\x41\x01\x03R\x05users\x12,\n\x0fnext_page_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\rnextPageToken\x12#\n\ntotal_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\ttotalSize\"\x8f\x01\n\x0eGetUserRequest\x12\x35\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x12\x37\n\x07user_id\x18\x03 \x01(\tB\x1e\xe2\x41\x01\x02\xfa\x41\x17\n\x15\x61pi.instill.tech/UserR\x06userIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"C\n\x0fGetUserResponse\x12\x30\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x04\xe2\x41\x01\x03R\x04user\"\x1d\n\x1bGetAuthenticatedUserRequest\"]\n\x1cGetAuthenticatedUserResponse\x12=\n\x04user\x18\x01 \x01(\x0b\x32#.core.mgmt.v1beta.AuthenticatedUserB\x04\xe2\x41\x01\x03R\x04user\"\xa1\x01\n\x1dPatchAuthenticatedUserRequest\x12=\n\x04user\x18\x01 \x01(\x0b\x32#.core.mgmt.v1beta.AuthenticatedUserB\x04\xe2\x41\x01\x02R\x04user\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"_\n\x1ePatchAuthenticatedUserResponse\x12=\n\x04user\x18\x01 \x01(\x0b\x32#.core.mgmt.v1beta.AuthenticatedUserB\x04\xe2\x41\x01\x03R\x04user\"-\n\x15\x43heckNamespaceRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\"\xea\x01\n\x16\x43heckNamespaceResponse\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x32.core.mgmt.v1beta.CheckNamespaceResponse.NamespaceR\x04type\"\x87\x01\n\tNamespace\x12\x19\n\x15NAMESPACE_UNSPECIFIED\x10\x00\x12\x17\n\x13NAMESPACE_AVAILABLE\x10\x01\x12\x12\n\x0eNAMESPACE_USER\x10\x02\x12\x1a\n\x16NAMESPACE_ORGANIZATION\x10\x03\x12\x16\n\x12NAMESPACE_RESERVED\x10\x04\"2\n\x1a\x43heckNamespaceAdminRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\"\x83\x03\n\x1b\x43heckNamespaceAdminResponse\x12K\n\x04type\x18\x01 \x01(\x0e\x32\x37.core.mgmt.v1beta.CheckNamespaceAdminResponse.NamespaceR\x04type\x12\x10\n\x03uid\x18\x02 \x01(\tR\x03uid\x12,\n\x04user\x18\x03 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserH\x00R\x04user\x12\x44\n\x0corganization\x18\x04 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationH\x00R\x0corganization\"\x87\x01\n\tNamespace\x12\x19\n\x15NAMESPACE_UNSPECIFIED\x10\x00\x12\x17\n\x13NAMESPACE_AVAILABLE\x10\x01\x12\x12\n\x0eNAMESPACE_USER\x10\x02\x12\x1a\n\x16NAMESPACE_ORGANIZATION\x10\x03\x12\x16\n\x12NAMESPACE_RESERVED\x10\x04\x42\x07\n\x05owner\"9\n\x1f\x43heckNamespaceByUIDAdminRequest\x12\x16\n\x03uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03uid\"\x8b\x03\n CheckNamespaceByUIDAdminResponse\x12P\n\x04type\x18\x01 \x01(\x0e\x32<.core.mgmt.v1beta.CheckNamespaceByUIDAdminResponse.NamespaceR\x04type\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12,\n\x04user\x18\x03 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserH\x00R\x04user\x12\x44\n\x0corganization\x18\x04 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationH\x00R\x0corganization\"\x87\x01\n\tNamespace\x12\x19\n\x15NAMESPACE_UNSPECIFIED\x10\x00\x12\x17\n\x13NAMESPACE_AVAILABLE\x10\x01\x12\x12\n\x0eNAMESPACE_USER\x10\x02\x12\x1a\n\x16NAMESPACE_ORGANIZATION\x10\x03\x12\x16\n\x12NAMESPACE_RESERVED\x10\x04\x42\x07\n\x05owner\"\x84\x05\n\x08\x41piToken\x12>\n\rlast_use_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUseTime\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x41\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\'\n\x0c\x61\x63\x63\x65ss_token\x18\x07 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x61\x63\x63\x65ssToken\x12<\n\x05state\x18\x08 \x01(\x0e\x32 .core.mgmt.v1beta.ApiToken.StateB\x04\xe2\x41\x01\x03R\x05state\x12#\n\ntoken_type\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\ttokenType\x12\x18\n\x03ttl\x18\n \x01(\x05\x42\x04\xe2\x41\x01\x04H\x00R\x03ttl\x12=\n\x0b\x65xpire_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\nexpireTime\"W\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_INACTIVE\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x11\n\rSTATE_EXPIRED\x10\x03:\x1e\xea\x41\x1b\n\x19\x61pi.instill.tech/ApiTokenB\x0c\n\nexpiration\"F\n\x12\x43reateTokenRequest\x12\x30\n\x05token\x18\x01 \x01(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenR\x05token\"M\n\x13\x43reateTokenResponse\x12\x36\n\x05token\x18\x01 \x01(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenB\x04\xe2\x41\x01\x03R\x05token\"\x82\x01\n\x11ListTokensRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x8f\x01\n\x12ListTokensResponse\x12\x32\n\x06tokens\x18\x01 \x03(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenR\x06tokens\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"V\n\x0fGetTokenRequest\x12=\n\x08token_id\x18\x02 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/ApiTokenR\x07tokenIdJ\x04\x08\x01\x10\x02\"J\n\x10GetTokenResponse\x12\x36\n\x05token\x18\x01 \x01(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenB\x04\xe2\x41\x01\x03R\x05token\"Y\n\x12\x44\x65leteTokenRequest\x12=\n\x08token_id\x18\x02 \x01(\tB\"\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/ApiTokenR\x07tokenIdJ\x04\x08\x01\x10\x02\"\x15\n\x13\x44\x65leteTokenResponse\"\x16\n\x14ValidateTokenRequest\"8\n\x15ValidateTokenResponse\x12\x1f\n\x08user_uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x07userUid\"J\n\x19GetRemainingCreditRequest\x12\'\n\x0cnamespace_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceIdJ\x04\x08\x01\x10\x02\"\x8e\x01\n\x1aGetRemainingCreditResponse\x12$\n\nperishable\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\nperishable\x12(\n\x0cimperishable\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x0cimperishable\x12\x1a\n\x05total\x18\x04 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05totalJ\x04\x08\x01\x10\x02\"K\n\x1eGetRemainingCreditAdminRequest\x12#\n\rnamespace_uid\x18\x02 \x01(\tR\x0cnamespaceUidJ\x04\x08\x01\x10\x02\"9\n\x1fGetRemainingCreditAdminResponse\x12\x16\n\x06\x61mount\x18\x01 \x01(\x02R\x06\x61mount\"y\n\x1aSubtractCreditAdminRequest\x12\x16\n\x06\x61mount\x18\x02 \x01(\x02R\x06\x61mount\x12\x18\n\x07\x63oncept\x18\x03 \x01(\tR\x07\x63oncept\x12#\n\rnamespace_uid\x18\x04 \x01(\tR\x0cnamespaceUidJ\x04\x08\x01\x10\x02\"5\n\x1bSubtractCreditAdminResponse\x12\x16\n\x06\x61mount\x18\x01 \x01(\x02R\x06\x61mount\"\\\n\x16\x41uthTokenIssuerRequest\x12 \n\x08username\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08username\x12 \n\x08password\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x08password\"\xec\x01\n\x17\x41uthTokenIssuerResponse\x12`\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\x0b\x32=.core.mgmt.v1beta.AuthTokenIssuerResponse.UnsignedAccessTokenR\x0b\x61\x63\x63\x65ssToken\x1ao\n\x13UnsignedAccessToken\x12\x10\n\x03\x61ud\x18\x01 \x01(\tR\x03\x61ud\x12\x10\n\x03iss\x18\x02 \x01(\tR\x03iss\x12\x10\n\x03sub\x18\x03 \x01(\tR\x03sub\x12\x10\n\x03jti\x18\x04 \x01(\tR\x03jti\x12\x10\n\x03\x65xp\x18\x05 \x01(\x05R\x03\x65xp\"V\n\x10\x41uthLoginRequest\x12 \n\x08username\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x08username\x12 \n\x08password\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x08password\"6\n\x11\x41uthLoginResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\"\x13\n\x11\x41uthLogoutRequest\"\x14\n\x12\x41uthLogoutResponse\" \n\x1e\x41uthValidateAccessTokenRequest\"!\n\x1f\x41uthValidateAccessTokenResponse\"a\n\x19\x41uthChangePasswordRequest\x12!\n\x0cold_password\x18\x01 \x01(\tR\x0boldPassword\x12!\n\x0cnew_password\x18\x02 \x01(\tR\x0bnewPassword\"\x1c\n\x1a\x41uthChangePasswordResponse\"\xe0\x03\n\x0cOrganization\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x41\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x32\n\x05owner\x18\x0b \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x04\xe2\x41\x01\x03R\x05owner\x12\x45\n\x07profile\x18\x0c \x01(\x0b\x32%.core.mgmt.v1beta.OrganizationProfileB\x04\xe2\x41\x01\x02R\x07profile\x12\x42\n\npermission\x18\r \x01(\x0b\x32\x1c.core.mgmt.v1beta.PermissionB\x04\xe2\x41\x01\x03R\npermission:C\xea\x41@\n\x1d\x61pi.instill.tech/Organization\x12\x1forganizations/{organization.id}\"\xf7\x01\n\x18ListOrganizationsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x35\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\xba\x01\n\x19ListOrganizationsResponse\x12J\n\rorganizations\x18\x01 \x03(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03R\rorganizations\x12,\n\x0fnext_page_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\rnextPageToken\x12#\n\ntotal_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\ttotalSize\"_\n\x19\x43reateOrganizationRequest\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\"f\n\x1a\x43reateOrganizationResponse\x12H\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03R\x0corganization\"\xaf\x01\n\x16GetOrganizationRequest\x12\x35\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x12O\n\x0forganization_id\x18\x03 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1d\x61pi.instill.tech/OrganizationR\x0eorganizationIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"c\n\x17GetOrganizationResponse\x12H\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03R\x0corganization\"\xd1\x01\n\x19UpdateOrganizationRequest\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\x12-\n\x0forganization_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationId\"f\n\x1aUpdateOrganizationResponse\x12H\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03R\x0corganization\"r\n\x19\x44\x65leteOrganizationRequest\x12O\n\x0forganization_id\x18\x02 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1d\x61pi.instill.tech/OrganizationR\x0eorganizationIdJ\x04\x08\x01\x10\x02\"\x1c\n\x1a\x44\x65leteOrganizationResponse\"\xac\x02\n\x16OrganizationMembership\x12=\n\x04name\x18\x01 \x01(\tB)\x92\x41\"\xca>\x1f\xfa\x02\x1corganization_membership_name\xe2\x41\x01\x03R\x04name\x12\x18\n\x04role\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x04role\x12=\n\x05state\x18\x04 \x01(\x0e\x32!.core.mgmt.v1beta.MembershipStateB\x04\xe2\x41\x01\x03R\x05state\x12\x30\n\x04user\x18\x05 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x04\xe2\x41\x01\x03R\x04user\x12H\n\x0corganization\x18\x06 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03R\x0corganization\"\x9c\x02\n\x0eUserMembership\x12\x35\n\x04name\x18\x01 \x01(\tB!\x92\x41\x1a\xca>\x17\xfa\x02\x14user_membership_name\xe2\x41\x01\x03R\x04name\x12\x18\n\x04role\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x04role\x12=\n\x05state\x18\x04 \x01(\x0e\x32!.core.mgmt.v1beta.MembershipStateB\x04\xe2\x41\x01\x02R\x05state\x12\x30\n\x04user\x18\x05 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x04\xe2\x41\x01\x03R\x04user\x12H\n\x0corganization\x18\x06 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x04\xe2\x41\x01\x03R\x0corganization\"A\n\x1aListUserMembershipsRequest\x12\x1d\n\x07user_id\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02R\x06userIdJ\x04\x08\x05\x10\x06\"g\n\x1bListUserMembershipsResponse\x12H\n\x0bmemberships\x18\x01 \x03(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x04\xe2\x41\x01\x03R\x0bmemberships\"\xae\x01\n\x18GetUserMembershipRequest\x12\x35\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x12\x1d\n\x07user_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x06userId\x12-\n\x0forganization_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"c\n\x19GetUserMembershipResponse\x12\x46\n\nmembership\x18\x01 \x01(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x04\xe2\x41\x01\x03R\nmembership\"\xf6\x01\n\x1bUpdateUserMembershipRequest\x12\x46\n\nmembership\x18\x01 \x01(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x04\xe2\x41\x01\x02R\nmembership\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\x12\x1d\n\x07user_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x06userId\x12-\n\x0forganization_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationId\"f\n\x1cUpdateUserMembershipResponse\x12\x46\n\nmembership\x18\x01 \x01(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x04\xe2\x41\x01\x03R\nmembership\"q\n\x1b\x44\x65leteUserMembershipRequest\x12\x1d\n\x07user_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x06userId\x12-\n\x0forganization_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationIdJ\x04\x08\x01\x10\x02\"\x1e\n\x1c\x44\x65leteUserMembershipResponse\"Y\n\"ListOrganizationMembershipsRequest\x12-\n\x0forganization_id\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationIdJ\x04\x08\x05\x10\x06\"w\n#ListOrganizationMembershipsResponse\x12P\n\x0bmemberships\x18\x01 \x03(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x04\xe2\x41\x01\x03R\x0bmemberships\"\xb6\x01\n GetOrganizationMembershipRequest\x12\x35\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x12-\n\x0forganization_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationId\x12\x1d\n\x07user_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x06userIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"s\n!GetOrganizationMembershipResponse\x12N\n\nmembership\x18\x01 \x01(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x04\xe2\x41\x01\x03R\nmembership\"\x86\x02\n#UpdateOrganizationMembershipRequest\x12N\n\nmembership\x18\x01 \x01(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x04\xe2\x41\x01\x02R\nmembership\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\x12-\n\x0forganization_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationId\x12\x1d\n\x07user_id\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x06userId\"v\n$UpdateOrganizationMembershipResponse\x12N\n\nmembership\x18\x01 \x01(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x04\xe2\x41\x01\x03R\nmembership\"y\n#DeleteOrganizationMembershipRequest\x12-\n\x0forganization_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationId\x12\x1d\n\x07user_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x06userIdJ\x04\x08\x01\x10\x02\"&\n$DeleteOrganizationMembershipResponse\"\xd0\x04\n\x18StripeSubscriptionDetail\x12\'\n\x0cproduct_name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x0bproductName\x12\x14\n\x02id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x02id\x12\x1d\n\x07item_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x06itemId\x12\x1a\n\x05price\x18\x04 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05price\x12*\n\x0b\x63\x61nceled_at\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x03H\x00R\ncanceledAt\x88\x01\x01\x12&\n\ttrial_end\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x03H\x01R\x08trialEnd\x88\x01\x01\x12O\n\x06status\x18\x07 \x01(\x0e\x32\x31.core.mgmt.v1beta.StripeSubscriptionDetail.StatusB\x04\xe2\x41\x01\x03R\x06status\x12&\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\"\xce\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11STATUS_INCOMPLETE\x10\x01\x12\x1d\n\x19STATUS_INCOMPLETE_EXPIRED\x10\x02\x12\x13\n\x0fSTATUS_TRIALING\x10\x03\x12\x11\n\rSTATUS_ACTIVE\x10\x04\x12\x13\n\x0fSTATUS_PAST_DUE\x10\x05\x12\x13\n\x0fSTATUS_CANCELED\x10\x06\x12\x11\n\rSTATUS_UNPAID\x10\x07\x12\x11\n\rSTATUS_PAUSED\x10\x08\x42\x0e\n\x0c_canceled_atB\x0c\n\n_trial_end\"\xda\x01\n\x10UserSubscription\x12\x41\n\x04plan\x18\x01 \x01(\x0e\x32\'.core.mgmt.v1beta.UserSubscription.PlanB\x04\xe2\x41\x01\x03R\x04plan\x12H\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32*.core.mgmt.v1beta.StripeSubscriptionDetailB\x04\xe2\x41\x01\x03R\x06\x64\x65tail\"9\n\x04Plan\x12\x14\n\x10PLAN_UNSPECIFIED\x10\x00\x12\r\n\tPLAN_FREE\x10\x01\x12\x0c\n\x08PLAN_PRO\x10\x02\"\xab\x02\n\x18OrganizationSubscription\x12I\n\x04plan\x18\x01 \x01(\x0e\x32/.core.mgmt.v1beta.OrganizationSubscription.PlanB\x04\xe2\x41\x01\x03R\x04plan\x12H\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32*.core.mgmt.v1beta.StripeSubscriptionDetailB\x04\xe2\x41\x01\x03R\x06\x64\x65tail\x12#\n\nused_seats\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\tusedSeats\"O\n\x04Plan\x12\x14\n\x10PLAN_UNSPECIFIED\x10\x00\x12\r\n\tPLAN_FREE\x10\x01\x12\r\n\tPLAN_TEAM\x10\x02\x12\x13\n\x0fPLAN_ENTERPRISE\x10\x03J\x04\x08\x03\x10\x04\")\n\'GetAuthenticatedUserSubscriptionRequest\"x\n(GetAuthenticatedUserSubscriptionResponse\x12L\n\x0csubscription\x18\x01 \x01(\x0b\x32\".core.mgmt.v1beta.UserSubscriptionB\x04\xe2\x41\x01\x03R\x0csubscription\"Y\n\"GetOrganizationSubscriptionRequest\x12-\n\x0forganization_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0eorganizationIdJ\x04\x08\x01\x10\x02\"{\n#GetOrganizationSubscriptionResponse\x12T\n\x0csubscription\x18\x01 \x01(\x0b\x32*.core.mgmt.v1beta.OrganizationSubscriptionB\x04\xe2\x41\x01\x03R\x0csubscription\"@\n\x1fGetUserSubscriptionAdminRequest\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userIdJ\x04\x08\x01\x10\x02\"j\n GetUserSubscriptionAdminResponse\x12\x46\n\x0csubscription\x18\x01 \x01(\x0b\x32\".core.mgmt.v1beta.UserSubscriptionR\x0csubscription\"X\n\'GetOrganizationSubscriptionAdminRequest\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationIdJ\x04\x08\x01\x10\x02\"z\n(GetOrganizationSubscriptionAdminResponse\x12N\n\x0csubscription\x18\x01 \x01(\x0b\x32*.core.mgmt.v1beta.OrganizationSubscriptionR\x0csubscription*;\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02*Y\n\tOwnerType\x12\x1a\n\x16OWNER_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fOWNER_TYPE_USER\x10\x01\x12\x1b\n\x17OWNER_TYPE_ORGANIZATION\x10\x02*n\n\x0fMembershipState\x12 \n\x1cMEMBERSHIP_STATE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MEMBERSHIP_STATE_ACTIVE\x10\x01\x12\x1c\n\x18MEMBERSHIP_STATE_PENDING\x10\x02*y\n\x10OnboardingStatus\x12!\n\x1dONBOARDING_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dONBOARDING_STATUS_IN_PROGRESS\x10\x01\x12\x1f\n\x1bONBOARDING_STATUS_COMPLETED\x10\x02\x42\xc2\x01\n\x14\x63om.core.mgmt.v1betaB\tMgmtProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\tMgmtProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._options = None
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\342A\001\003'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _READINESSRESPONSE.fields_by_name['health_check_response']._options = None
  _READINESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\342A\001\003'
  _PERMISSION.fields_by_name['can_edit']._options = None
  _PERMISSION.fields_by_name['can_edit']._serialized_options = b'\342A\001\003'
  _USERPROFILE_SOCIALPROFILELINKSENTRY._options = None
  _USERPROFILE_SOCIALPROFILELINKSENTRY._serialized_options = b'8\001'
  _USERPROFILE.fields_by_name['display_name']._options = None
  _USERPROFILE.fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _USERPROFILE.fields_by_name['bio']._options = None
  _USERPROFILE.fields_by_name['bio']._serialized_options = b'\342A\001\001'
  _USERPROFILE.fields_by_name['avatar']._options = None
  _USERPROFILE.fields_by_name['avatar']._serialized_options = b'\342A\001\001'
  _USERPROFILE.fields_by_name['public_email']._options = None
  _USERPROFILE.fields_by_name['public_email']._serialized_options = b'\342A\001\001'
  _USERPROFILE.fields_by_name['company_name']._options = None
  _USERPROFILE.fields_by_name['company_name']._serialized_options = b'\342A\001\001'
  _USERPROFILE.fields_by_name['social_profile_links']._options = None
  _USERPROFILE.fields_by_name['social_profile_links']._serialized_options = b'\342A\001\001'
  _ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY._options = None
  _ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY._serialized_options = b'8\001'
  _ORGANIZATIONPROFILE.fields_by_name['display_name']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _ORGANIZATIONPROFILE.fields_by_name['bio']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['bio']._serialized_options = b'\342A\001\001'
  _ORGANIZATIONPROFILE.fields_by_name['avatar']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['avatar']._serialized_options = b'\342A\001\001'
  _ORGANIZATIONPROFILE.fields_by_name['public_email']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['public_email']._serialized_options = b'\342A\001\001'
  _ORGANIZATIONPROFILE.fields_by_name['social_profile_links']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['social_profile_links']._serialized_options = b'\342A\001\001'
  _AUTHENTICATEDUSER.fields_by_name['name']._options = None
  _AUTHENTICATEDUSER.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _AUTHENTICATEDUSER.fields_by_name['uid']._options = None
  _AUTHENTICATEDUSER.fields_by_name['uid']._serialized_options = b'\342A\001\005'
  _AUTHENTICATEDUSER.fields_by_name['id']._options = None
  _AUTHENTICATEDUSER.fields_by_name['id']._serialized_options = b'\342A\001\002'
  _AUTHENTICATEDUSER.fields_by_name['create_time']._options = None
  _AUTHENTICATEDUSER.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _AUTHENTICATEDUSER.fields_by_name['update_time']._options = None
  _AUTHENTICATEDUSER.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _AUTHENTICATEDUSER.fields_by_name['email']._options = None
  _AUTHENTICATEDUSER.fields_by_name['email']._serialized_options = b'\342A\001\002'
  _AUTHENTICATEDUSER.fields_by_name['customer_id']._options = None
  _AUTHENTICATEDUSER.fields_by_name['customer_id']._serialized_options = b'\342A\001\003'
  _AUTHENTICATEDUSER.fields_by_name['role']._options = None
  _AUTHENTICATEDUSER.fields_by_name['role']._serialized_options = b'\342A\001\001'
  _AUTHENTICATEDUSER.fields_by_name['newsletter_subscription']._options = None
  _AUTHENTICATEDUSER.fields_by_name['newsletter_subscription']._serialized_options = b'\342A\001\002'
  _AUTHENTICATEDUSER.fields_by_name['cookie_token']._options = None
  _AUTHENTICATEDUSER.fields_by_name['cookie_token']._serialized_options = b'\342A\001\001'
  _AUTHENTICATEDUSER.fields_by_name['onboarding_status']._options = None
  _AUTHENTICATEDUSER.fields_by_name['onboarding_status']._serialized_options = b'\342A\001\001'
  _AUTHENTICATEDUSER.fields_by_name['profile']._options = None
  _AUTHENTICATEDUSER.fields_by_name['profile']._serialized_options = b'\342A\001\003'
  _AUTHENTICATEDUSER._options = None
  _AUTHENTICATEDUSER._serialized_options = b'\352A$\n\"api.instill.tech/AuthenticatedUser'
  _OWNER.fields_by_name['user']._options = None
  _OWNER.fields_by_name['user']._serialized_options = b'\342A\001\003'
  _OWNER.fields_by_name['organization']._options = None
  _OWNER.fields_by_name['organization']._serialized_options = b'\342A\001\003'
  _USER.fields_by_name['name']._options = None
  _USER.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _USER.fields_by_name['uid']._options = None
  _USER.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _USER.fields_by_name['id']._options = None
  _USER.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _USER.fields_by_name['create_time']._options = None
  _USER.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _USER.fields_by_name['update_time']._options = None
  _USER.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _USER._options = None
  _USER._serialized_options = b'\352A:\n\025api.instill.tech/User\022\017users/{user.id}\022\020users/{user.uid}'
  _LISTUSERSADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERSADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERSADMINREQUEST.fields_by_name['view']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERSADMINREQUEST.fields_by_name['filter']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERSREQUEST.fields_by_name['view']._options = None
  _LISTUSERSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTUSERSRESPONSE.fields_by_name['users']._options = None
  _LISTUSERSRESPONSE.fields_by_name['users']._serialized_options = b'\342A\001\003'
  _LISTUSERSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTUSERSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\342A\001\003'
  _LISTUSERSRESPONSE.fields_by_name['total_size']._options = None
  _LISTUSERSRESPONSE.fields_by_name['total_size']._serialized_options = b'\342A\001\003'
  _GETUSERREQUEST.fields_by_name['view']._options = None
  _GETUSERREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETUSERREQUEST.fields_by_name['user_id']._options = None
  _GETUSERREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002\372A\027\n\025api.instill.tech/User'
  _GETUSERRESPONSE.fields_by_name['user']._options = None
  _GETUSERRESPONSE.fields_by_name['user']._serialized_options = b'\342A\001\003'
  _GETAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._options = None
  _GETAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._serialized_options = b'\342A\001\003'
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['user']._options = None
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['user']._serialized_options = b'\342A\001\002'
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['update_mask']._options = None
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _PATCHAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._options = None
  _PATCHAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._serialized_options = b'\342A\001\003'
  _CHECKNAMESPACEREQUEST.fields_by_name['id']._options = None
  _CHECKNAMESPACEREQUEST.fields_by_name['id']._serialized_options = b'\342A\001\002'
  _CHECKNAMESPACEADMINREQUEST.fields_by_name['id']._options = None
  _CHECKNAMESPACEADMINREQUEST.fields_by_name['id']._serialized_options = b'\342A\001\002'
  _CHECKNAMESPACEBYUIDADMINREQUEST.fields_by_name['uid']._options = None
  _CHECKNAMESPACEBYUIDADMINREQUEST.fields_by_name['uid']._serialized_options = b'\342A\001\002'
  _APITOKEN.fields_by_name['name']._options = None
  _APITOKEN.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['uid']._options = None
  _APITOKEN.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['id']._options = None
  _APITOKEN.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _APITOKEN.fields_by_name['create_time']._options = None
  _APITOKEN.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['update_time']._options = None
  _APITOKEN.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['access_token']._options = None
  _APITOKEN.fields_by_name['access_token']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['state']._options = None
  _APITOKEN.fields_by_name['state']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['token_type']._options = None
  _APITOKEN.fields_by_name['token_type']._serialized_options = b'\342A\001\003'
  _APITOKEN.fields_by_name['ttl']._options = None
  _APITOKEN.fields_by_name['ttl']._serialized_options = b'\342A\001\004'
  _APITOKEN._options = None
  _APITOKEN._serialized_options = b'\352A\033\n\031api.instill.tech/ApiToken'
  _CREATETOKENRESPONSE.fields_by_name['token']._options = None
  _CREATETOKENRESPONSE.fields_by_name['token']._serialized_options = b'\342A\001\003'
  _LISTTOKENSREQUEST.fields_by_name['page_size']._options = None
  _LISTTOKENSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTTOKENSREQUEST.fields_by_name['page_token']._options = None
  _LISTTOKENSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _GETTOKENREQUEST.fields_by_name['token_id']._options = None
  _GETTOKENREQUEST.fields_by_name['token_id']._serialized_options = b'\342A\001\002\372A\033\n\031api.instill.tech/ApiToken'
  _GETTOKENRESPONSE.fields_by_name['token']._options = None
  _GETTOKENRESPONSE.fields_by_name['token']._serialized_options = b'\342A\001\003'
  _DELETETOKENREQUEST.fields_by_name['token_id']._options = None
  _DELETETOKENREQUEST.fields_by_name['token_id']._serialized_options = b'\342A\001\002\372A\033\n\031api.instill.tech/ApiToken'
  _VALIDATETOKENRESPONSE.fields_by_name['user_uid']._options = None
  _VALIDATETOKENRESPONSE.fields_by_name['user_uid']._serialized_options = b'\342A\001\003'
  _GETREMAININGCREDITREQUEST.fields_by_name['namespace_id']._options = None
  _GETREMAININGCREDITREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _GETREMAININGCREDITRESPONSE.fields_by_name['perishable']._options = None
  _GETREMAININGCREDITRESPONSE.fields_by_name['perishable']._serialized_options = b'\342A\001\003'
  _GETREMAININGCREDITRESPONSE.fields_by_name['imperishable']._options = None
  _GETREMAININGCREDITRESPONSE.fields_by_name['imperishable']._serialized_options = b'\342A\001\003'
  _GETREMAININGCREDITRESPONSE.fields_by_name['total']._options = None
  _GETREMAININGCREDITRESPONSE.fields_by_name['total']._serialized_options = b'\342A\001\003'
  _AUTHTOKENISSUERREQUEST.fields_by_name['username']._options = None
  _AUTHTOKENISSUERREQUEST.fields_by_name['username']._serialized_options = b'\342A\001\002'
  _AUTHTOKENISSUERREQUEST.fields_by_name['password']._options = None
  _AUTHTOKENISSUERREQUEST.fields_by_name['password']._serialized_options = b'\342A\001\002'
  _AUTHLOGINREQUEST.fields_by_name['username']._options = None
  _AUTHLOGINREQUEST.fields_by_name['username']._serialized_options = b'\342A\001\002'
  _AUTHLOGINREQUEST.fields_by_name['password']._options = None
  _AUTHLOGINREQUEST.fields_by_name['password']._serialized_options = b'\342A\001\002'
  _ORGANIZATION.fields_by_name['name']._options = None
  _ORGANIZATION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _ORGANIZATION.fields_by_name['uid']._options = None
  _ORGANIZATION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _ORGANIZATION.fields_by_name['id']._options = None
  _ORGANIZATION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _ORGANIZATION.fields_by_name['create_time']._options = None
  _ORGANIZATION.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _ORGANIZATION.fields_by_name['update_time']._options = None
  _ORGANIZATION.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _ORGANIZATION.fields_by_name['owner']._options = None
  _ORGANIZATION.fields_by_name['owner']._serialized_options = b'\342A\001\003'
  _ORGANIZATION.fields_by_name['profile']._options = None
  _ORGANIZATION.fields_by_name['profile']._serialized_options = b'\342A\001\002'
  _ORGANIZATION.fields_by_name['permission']._options = None
  _ORGANIZATION.fields_by_name['permission']._serialized_options = b'\342A\001\003'
  _ORGANIZATION._options = None
  _ORGANIZATION._serialized_options = b'\352A@\n\035api.instill.tech/Organization\022\037organizations/{organization.id}'
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONSREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONSRESPONSE.fields_by_name['organizations']._options = None
  _LISTORGANIZATIONSRESPONSE.fields_by_name['organizations']._serialized_options = b'\342A\001\003'
  _LISTORGANIZATIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTORGANIZATIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\342A\001\003'
  _LISTORGANIZATIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTORGANIZATIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\342A\001\003'
  _CREATEORGANIZATIONRESPONSE.fields_by_name['organization']._options = None
  _CREATEORGANIZATIONRESPONSE.fields_by_name['organization']._serialized_options = b'\342A\001\003'
  _GETORGANIZATIONREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002\372A\037\n\035api.instill.tech/Organization'
  _GETORGANIZATIONRESPONSE.fields_by_name['organization']._options = None
  _GETORGANIZATIONRESPONSE.fields_by_name['organization']._serialized_options = b'\342A\001\003'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONRESPONSE.fields_by_name['organization']._options = None
  _UPDATEORGANIZATIONRESPONSE.fields_by_name['organization']._serialized_options = b'\342A\001\003'
  _DELETEORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _DELETEORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002\372A\037\n\035api.instill.tech/Organization'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['name']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['name']._serialized_options = b'\222A\"\312>\037\372\002\034organization_membership_name\342A\001\003'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['role']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['role']._serialized_options = b'\342A\001\002'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['state']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['state']._serialized_options = b'\342A\001\003'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['user']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['user']._serialized_options = b'\342A\001\003'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['organization']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['organization']._serialized_options = b'\342A\001\003'
  _USERMEMBERSHIP.fields_by_name['name']._options = None
  _USERMEMBERSHIP.fields_by_name['name']._serialized_options = b'\222A\032\312>\027\372\002\024user_membership_name\342A\001\003'
  _USERMEMBERSHIP.fields_by_name['role']._options = None
  _USERMEMBERSHIP.fields_by_name['role']._serialized_options = b'\342A\001\003'
  _USERMEMBERSHIP.fields_by_name['state']._options = None
  _USERMEMBERSHIP.fields_by_name['state']._serialized_options = b'\342A\001\002'
  _USERMEMBERSHIP.fields_by_name['user']._options = None
  _USERMEMBERSHIP.fields_by_name['user']._serialized_options = b'\342A\001\003'
  _USERMEMBERSHIP.fields_by_name['organization']._options = None
  _USERMEMBERSHIP.fields_by_name['organization']._serialized_options = b'\342A\001\003'
  _LISTUSERMEMBERSHIPSREQUEST.fields_by_name['user_id']._options = None
  _LISTUSERMEMBERSHIPSREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _LISTUSERMEMBERSHIPSRESPONSE.fields_by_name['memberships']._options = None
  _LISTUSERMEMBERSHIPSRESPONSE.fields_by_name['memberships']._serialized_options = b'\342A\001\003'
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['view']._options = None
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _GETUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _GETUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\342A\001\003'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['membership']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['membership']._serialized_options = b'\342A\001\002'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _UPDATEUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _UPDATEUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\342A\001\003'
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _LISTORGANIZATIONMEMBERSHIPSREQUEST.fields_by_name['organization_id']._options = None
  _LISTORGANIZATIONMEMBERSHIPSREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _LISTORGANIZATIONMEMBERSHIPSRESPONSE.fields_by_name['memberships']._options = None
  _LISTORGANIZATIONMEMBERSHIPSRESPONSE.fields_by_name['memberships']._serialized_options = b'\342A\001\003'
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _GETORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _GETORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\342A\001\003'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['membership']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['membership']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\342A\001\003'
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\342A\001\002'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['product_name']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['product_name']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['id']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['id']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['item_id']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['item_id']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['price']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['price']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['canceled_at']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['canceled_at']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['trial_end']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['trial_end']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['status']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['description']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _USERSUBSCRIPTION.fields_by_name['plan']._options = None
  _USERSUBSCRIPTION.fields_by_name['plan']._serialized_options = b'\342A\001\003'
  _USERSUBSCRIPTION.fields_by_name['detail']._options = None
  _USERSUBSCRIPTION.fields_by_name['detail']._serialized_options = b'\342A\001\003'
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['plan']._options = None
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['plan']._serialized_options = b'\342A\001\003'
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['detail']._options = None
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['detail']._serialized_options = b'\342A\001\003'
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['used_seats']._options = None
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['used_seats']._serialized_options = b'\342A\001\003'
  _GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._options = None
  _GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._serialized_options = b'\342A\001\003'
  _GETORGANIZATIONSUBSCRIPTIONREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONSUBSCRIPTIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\342A\001\002'
  _GETORGANIZATIONSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._options = None
  _GETORGANIZATIONSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._serialized_options = b'\342A\001\003'
  _globals['_VIEW']._serialized_start=15804
  _globals['_VIEW']._serialized_end=15863
  _globals['_OWNERTYPE']._serialized_start=15865
  _globals['_OWNERTYPE']._serialized_end=15954
  _globals['_MEMBERSHIPSTATE']._serialized_start=15956
  _globals['_MEMBERSHIPSTATE']._serialized_end=16066
  _globals['_ONBOARDINGSTATUS']._serialized_start=16068
  _globals['_ONBOARDINGSTATUS']._serialized_end=16189
  _globals['_LIVENESSREQUEST']._serialized_start=270
  _globals['_LIVENESSREQUEST']._serialized_end=420
  _globals['_LIVENESSRESPONSE']._serialized_start=422
  _globals['_LIVENESSRESPONSE']._serialized_end=546
  _globals['_READINESSREQUEST']._serialized_start=549
  _globals['_READINESSREQUEST']._serialized_end=700
  _globals['_READINESSRESPONSE']._serialized_start=702
  _globals['_READINESSRESPONSE']._serialized_end=827
  _globals['_PERMISSION']._serialized_start=829
  _globals['_PERMISSION']._serialized_end=874
  _globals['_USERPROFILE']._serialized_start=877
  _globals['_USERPROFILE']._serialized_end=1344
  _globals['_USERPROFILE_SOCIALPROFILELINKSENTRY']._serialized_start=1205
  _globals['_USERPROFILE_SOCIALPROFILELINKSENTRY']._serialized_end=1274
  _globals['_ORGANIZATIONPROFILE']._serialized_start=1347
  _globals['_ORGANIZATIONPROFILE']._serialized_end=1767
  _globals['_ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY']._serialized_start=1205
  _globals['_ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY']._serialized_end=1274
  _globals['_AUTHENTICATEDUSER']._serialized_start=1770
  _globals['_AUTHENTICATEDUSER']._serialized_end=2432
  _globals['_OWNER']._serialized_start=2435
  _globals['_OWNER']._serialized_end=2579
  _globals['_USER']._serialized_start=2582
  _globals['_USER']._serialized_end=2927
  _globals['_LISTUSERSADMINREQUEST']._serialized_start=2930
  _globals['_LISTUSERSADMINREQUEST']._serialized_end=3174
  _globals['_LISTUSERSADMINRESPONSE']._serialized_start=3177
  _globals['_LISTUSERSADMINRESPONSE']._serialized_end=3318
  _globals['_GETUSERADMINREQUEST']._serialized_start=3320
  _globals['_GETUSERADMINREQUEST']._serialized_end=3430
  _globals['_GETUSERADMINRESPONSE']._serialized_start=3432
  _globals['_GETUSERADMINRESPONSE']._serialized_end=3498
  _globals['_LOOKUPUSERADMINREQUEST']._serialized_start=3500
  _globals['_LOOKUPUSERADMINREQUEST']._serialized_end=3615
  _globals['_LOOKUPUSERADMINRESPONSE']._serialized_start=3617
  _globals['_LOOKUPUSERADMINRESPONSE']._serialized_end=3686
  _globals['_LISTORGANIZATIONSADMINREQUEST']._serialized_start=3689
  _globals['_LISTORGANIZATIONSADMINREQUEST']._serialized_end=3917
  _globals['_LISTORGANIZATIONSADMINRESPONSE']._serialized_start=3920
  _globals['_LISTORGANIZATIONSADMINRESPONSE']._serialized_end=4093
  _globals['_GETORGANIZATIONADMINREQUEST']._serialized_start=4096
  _globals['_GETORGANIZATIONADMINREQUEST']._serialized_end=4230
  _globals['_GETORGANIZATIONADMINRESPONSE']._serialized_start=4232
  _globals['_GETORGANIZATIONADMINRESPONSE']._serialized_end=4330
  _globals['_LOOKUPORGANIZATIONADMINREQUEST']._serialized_start=4333
  _globals['_LOOKUPORGANIZATIONADMINREQUEST']._serialized_end=4472
  _globals['_LOOKUPORGANIZATIONADMINRESPONSE']._serialized_start=4474
  _globals['_LOOKUPORGANIZATIONADMINRESPONSE']._serialized_end=4575
  _globals['_LISTUSERSREQUEST']._serialized_start=4578
  _globals['_LISTUSERSREQUEST']._serialized_end=4817
  _globals['_LISTUSERSRESPONSE']._serialized_start=4820
  _globals['_LISTUSERSRESPONSE']._serialized_end=4974
  _globals['_GETUSERREQUEST']._serialized_start=4977
  _globals['_GETUSERREQUEST']._serialized_end=5120
  _globals['_GETUSERRESPONSE']._serialized_start=5122
  _globals['_GETUSERRESPONSE']._serialized_end=5189
  _globals['_GETAUTHENTICATEDUSERREQUEST']._serialized_start=5191
  _globals['_GETAUTHENTICATEDUSERREQUEST']._serialized_end=5220
  _globals['_GETAUTHENTICATEDUSERRESPONSE']._serialized_start=5222
  _globals['_GETAUTHENTICATEDUSERRESPONSE']._serialized_end=5315
  _globals['_PATCHAUTHENTICATEDUSERREQUEST']._serialized_start=5318
  _globals['_PATCHAUTHENTICATEDUSERREQUEST']._serialized_end=5479
  _globals['_PATCHAUTHENTICATEDUSERRESPONSE']._serialized_start=5481
  _globals['_PATCHAUTHENTICATEDUSERRESPONSE']._serialized_end=5576
  _globals['_CHECKNAMESPACEREQUEST']._serialized_start=5578
  _globals['_CHECKNAMESPACEREQUEST']._serialized_end=5623
  _globals['_CHECKNAMESPACERESPONSE']._serialized_start=5626
  _globals['_CHECKNAMESPACERESPONSE']._serialized_end=5860
  _globals['_CHECKNAMESPACERESPONSE_NAMESPACE']._serialized_start=5725
  _globals['_CHECKNAMESPACERESPONSE_NAMESPACE']._serialized_end=5860
  _globals['_CHECKNAMESPACEADMINREQUEST']._serialized_start=5862
  _globals['_CHECKNAMESPACEADMINREQUEST']._serialized_end=5912
  _globals['_CHECKNAMESPACEADMINRESPONSE']._serialized_start=5915
  _globals['_CHECKNAMESPACEADMINRESPONSE']._serialized_end=6302
  _globals['_CHECKNAMESPACEADMINRESPONSE_NAMESPACE']._serialized_start=5725
  _globals['_CHECKNAMESPACEADMINRESPONSE_NAMESPACE']._serialized_end=5860
  _globals['_CHECKNAMESPACEBYUIDADMINREQUEST']._serialized_start=6304
  _globals['_CHECKNAMESPACEBYUIDADMINREQUEST']._serialized_end=6361
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE']._serialized_start=6364
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE']._serialized_end=6759
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE_NAMESPACE']._serialized_start=5725
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE_NAMESPACE']._serialized_end=5860
  _globals['_APITOKEN']._serialized_start=6762
  _globals['_APITOKEN']._serialized_end=7406
  _globals['_APITOKEN_STATE']._serialized_start=7273
  _globals['_APITOKEN_STATE']._serialized_end=7360
  _globals['_CREATETOKENREQUEST']._serialized_start=7408
  _globals['_CREATETOKENREQUEST']._serialized_end=7478
  _globals['_CREATETOKENRESPONSE']._serialized_start=7480
  _globals['_CREATETOKENRESPONSE']._serialized_end=7557
  _globals['_LISTTOKENSREQUEST']._serialized_start=7560
  _globals['_LISTTOKENSREQUEST']._serialized_end=7690
  _globals['_LISTTOKENSRESPONSE']._serialized_start=7693
  _globals['_LISTTOKENSRESPONSE']._serialized_end=7836
  _globals['_GETTOKENREQUEST']._serialized_start=7838
  _globals['_GETTOKENREQUEST']._serialized_end=7924
  _globals['_GETTOKENRESPONSE']._serialized_start=7926
  _globals['_GETTOKENRESPONSE']._serialized_end=8000
  _globals['_DELETETOKENREQUEST']._serialized_start=8002
  _globals['_DELETETOKENREQUEST']._serialized_end=8091
  _globals['_DELETETOKENRESPONSE']._serialized_start=8093
  _globals['_DELETETOKENRESPONSE']._serialized_end=8114
  _globals['_VALIDATETOKENREQUEST']._serialized_start=8116
  _globals['_VALIDATETOKENREQUEST']._serialized_end=8138
  _globals['_VALIDATETOKENRESPONSE']._serialized_start=8140
  _globals['_VALIDATETOKENRESPONSE']._serialized_end=8196
  _globals['_GETREMAININGCREDITREQUEST']._serialized_start=8198
  _globals['_GETREMAININGCREDITREQUEST']._serialized_end=8272
  _globals['_GETREMAININGCREDITRESPONSE']._serialized_start=8275
  _globals['_GETREMAININGCREDITRESPONSE']._serialized_end=8417
  _globals['_GETREMAININGCREDITADMINREQUEST']._serialized_start=8419
  _globals['_GETREMAININGCREDITADMINREQUEST']._serialized_end=8494
  _globals['_GETREMAININGCREDITADMINRESPONSE']._serialized_start=8496
  _globals['_GETREMAININGCREDITADMINRESPONSE']._serialized_end=8553
  _globals['_SUBTRACTCREDITADMINREQUEST']._serialized_start=8555
  _globals['_SUBTRACTCREDITADMINREQUEST']._serialized_end=8676
  _globals['_SUBTRACTCREDITADMINRESPONSE']._serialized_start=8678
  _globals['_SUBTRACTCREDITADMINRESPONSE']._serialized_end=8731
  _globals['_AUTHTOKENISSUERREQUEST']._serialized_start=8733
  _globals['_AUTHTOKENISSUERREQUEST']._serialized_end=8825
  _globals['_AUTHTOKENISSUERRESPONSE']._serialized_start=8828
  _globals['_AUTHTOKENISSUERRESPONSE']._serialized_end=9064
  _globals['_AUTHTOKENISSUERRESPONSE_UNSIGNEDACCESSTOKEN']._serialized_start=8953
  _globals['_AUTHTOKENISSUERRESPONSE_UNSIGNEDACCESSTOKEN']._serialized_end=9064
  _globals['_AUTHLOGINREQUEST']._serialized_start=9066
  _globals['_AUTHLOGINREQUEST']._serialized_end=9152
  _globals['_AUTHLOGINRESPONSE']._serialized_start=9154
  _globals['_AUTHLOGINRESPONSE']._serialized_end=9208
  _globals['_AUTHLOGOUTREQUEST']._serialized_start=9210
  _globals['_AUTHLOGOUTREQUEST']._serialized_end=9229
  _globals['_AUTHLOGOUTRESPONSE']._serialized_start=9231
  _globals['_AUTHLOGOUTRESPONSE']._serialized_end=9251
  _globals['_AUTHVALIDATEACCESSTOKENREQUEST']._serialized_start=9253
  _globals['_AUTHVALIDATEACCESSTOKENREQUEST']._serialized_end=9285
  _globals['_AUTHVALIDATEACCESSTOKENRESPONSE']._serialized_start=9287
  _globals['_AUTHVALIDATEACCESSTOKENRESPONSE']._serialized_end=9320
  _globals['_AUTHCHANGEPASSWORDREQUEST']._serialized_start=9322
  _globals['_AUTHCHANGEPASSWORDREQUEST']._serialized_end=9419
  _globals['_AUTHCHANGEPASSWORDRESPONSE']._serialized_start=9421
  _globals['_AUTHCHANGEPASSWORDRESPONSE']._serialized_end=9449
  _globals['_ORGANIZATION']._serialized_start=9452
  _globals['_ORGANIZATION']._serialized_end=9932
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_start=9935
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_end=10182
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_start=10185
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_end=10371
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_start=10373
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_end=10468
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_start=10470
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_end=10572
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=10575
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=10750
  _globals['_GETORGANIZATIONRESPONSE']._serialized_start=10752
  _globals['_GETORGANIZATIONRESPONSE']._serialized_end=10851
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_start=10854
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_end=11063
  _globals['_UPDATEORGANIZATIONRESPONSE']._serialized_start=11065
  _globals['_UPDATEORGANIZATIONRESPONSE']._serialized_end=11167
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_start=11169
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_end=11283
  _globals['_DELETEORGANIZATIONRESPONSE']._serialized_start=11285
  _globals['_DELETEORGANIZATIONRESPONSE']._serialized_end=11313
  _globals['_ORGANIZATIONMEMBERSHIP']._serialized_start=11316
  _globals['_ORGANIZATIONMEMBERSHIP']._serialized_end=11616
  _globals['_USERMEMBERSHIP']._serialized_start=11619
  _globals['_USERMEMBERSHIP']._serialized_end=11903
  _globals['_LISTUSERMEMBERSHIPSREQUEST']._serialized_start=11905
  _globals['_LISTUSERMEMBERSHIPSREQUEST']._serialized_end=11970
  _globals['_LISTUSERMEMBERSHIPSRESPONSE']._serialized_start=11972
  _globals['_LISTUSERMEMBERSHIPSRESPONSE']._serialized_end=12075
  _globals['_GETUSERMEMBERSHIPREQUEST']._serialized_start=12078
  _globals['_GETUSERMEMBERSHIPREQUEST']._serialized_end=12252
  _globals['_GETUSERMEMBERSHIPRESPONSE']._serialized_start=12254
  _globals['_GETUSERMEMBERSHIPRESPONSE']._serialized_end=12353
  _globals['_UPDATEUSERMEMBERSHIPREQUEST']._serialized_start=12356
  _globals['_UPDATEUSERMEMBERSHIPREQUEST']._serialized_end=12602
  _globals['_UPDATEUSERMEMBERSHIPRESPONSE']._serialized_start=12604
  _globals['_UPDATEUSERMEMBERSHIPRESPONSE']._serialized_end=12706
  _globals['_DELETEUSERMEMBERSHIPREQUEST']._serialized_start=12708
  _globals['_DELETEUSERMEMBERSHIPREQUEST']._serialized_end=12821
  _globals['_DELETEUSERMEMBERSHIPRESPONSE']._serialized_start=12823
  _globals['_DELETEUSERMEMBERSHIPRESPONSE']._serialized_end=12853
  _globals['_LISTORGANIZATIONMEMBERSHIPSREQUEST']._serialized_start=12855
  _globals['_LISTORGANIZATIONMEMBERSHIPSREQUEST']._serialized_end=12944
  _globals['_LISTORGANIZATIONMEMBERSHIPSRESPONSE']._serialized_start=12946
  _globals['_LISTORGANIZATIONMEMBERSHIPSRESPONSE']._serialized_end=13065
  _globals['_GETORGANIZATIONMEMBERSHIPREQUEST']._serialized_start=13068
  _globals['_GETORGANIZATIONMEMBERSHIPREQUEST']._serialized_end=13250
  _globals['_GETORGANIZATIONMEMBERSHIPRESPONSE']._serialized_start=13252
  _globals['_GETORGANIZATIONMEMBERSHIPRESPONSE']._serialized_end=13367
  _globals['_UPDATEORGANIZATIONMEMBERSHIPREQUEST']._serialized_start=13370
  _globals['_UPDATEORGANIZATIONMEMBERSHIPREQUEST']._serialized_end=13632
  _globals['_UPDATEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_start=13634
  _globals['_UPDATEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_end=13752
  _globals['_DELETEORGANIZATIONMEMBERSHIPREQUEST']._serialized_start=13754
  _globals['_DELETEORGANIZATIONMEMBERSHIPREQUEST']._serialized_end=13875
  _globals['_DELETEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_start=13877
  _globals['_DELETEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_end=13915
  _globals['_STRIPESUBSCRIPTIONDETAIL']._serialized_start=13918
  _globals['_STRIPESUBSCRIPTIONDETAIL']._serialized_end=14510
  _globals['_STRIPESUBSCRIPTIONDETAIL_STATUS']._serialized_start=14274
  _globals['_STRIPESUBSCRIPTIONDETAIL_STATUS']._serialized_end=14480
  _globals['_USERSUBSCRIPTION']._serialized_start=14513
  _globals['_USERSUBSCRIPTION']._serialized_end=14731
  _globals['_USERSUBSCRIPTION_PLAN']._serialized_start=14674
  _globals['_USERSUBSCRIPTION_PLAN']._serialized_end=14731
  _globals['_ORGANIZATIONSUBSCRIPTION']._serialized_start=14734
  _globals['_ORGANIZATIONSUBSCRIPTION']._serialized_end=15033
  _globals['_ORGANIZATIONSUBSCRIPTION_PLAN']._serialized_start=14948
  _globals['_ORGANIZATIONSUBSCRIPTION_PLAN']._serialized_end=15027
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONREQUEST']._serialized_start=15035
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONREQUEST']._serialized_end=15076
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE']._serialized_start=15078
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE']._serialized_end=15198
  _globals['_GETORGANIZATIONSUBSCRIPTIONREQUEST']._serialized_start=15200
  _globals['_GETORGANIZATIONSUBSCRIPTIONREQUEST']._serialized_end=15289
  _globals['_GETORGANIZATIONSUBSCRIPTIONRESPONSE']._serialized_start=15291
  _globals['_GETORGANIZATIONSUBSCRIPTIONRESPONSE']._serialized_end=15414
  _globals['_GETUSERSUBSCRIPTIONADMINREQUEST']._serialized_start=15416
  _globals['_GETUSERSUBSCRIPTIONADMINREQUEST']._serialized_end=15480
  _globals['_GETUSERSUBSCRIPTIONADMINRESPONSE']._serialized_start=15482
  _globals['_GETUSERSUBSCRIPTIONADMINRESPONSE']._serialized_end=15588
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINREQUEST']._serialized_start=15590
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINREQUEST']._serialized_end=15678
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINRESPONSE']._serialized_start=15680
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINRESPONSE']._serialized_end=15802
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2


class ArtifactPublicServiceStub(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
                )
        self.CreateKnowledgeBase = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/CreateKnowledgeBase',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseResponse.FromString,
                )
        self.ListKnowledgeBases = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBases',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesResponse.FromString,
                )
        self.UpdateKnowledgeBase = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateKnowledgeBase',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseResponse.FromString,
                )
        self.DeleteKnowledgeBase = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBase',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseResponse.FromString,
                )
        self.UploadKnowledgeBaseFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UploadKnowledgeBaseFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileResponse.FromString,
                )
        self.DeleteKnowledgeBaseFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBaseFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileResponse.FromString,
                )
        self.ProcessKnowledgeBaseFiles = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ProcessKnowledgeBaseFiles',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesResponse.FromString,
                )
        self.ListKnowledgeBaseFiles = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBaseFiles',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesResponse.FromString,
                )
        self.ListChunks = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/ListChunks',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.FromString,
                )
        self.GetSourceFile = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/GetSourceFile',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.FromString,
                )
        self.UpdateChunk = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateChunk',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.FromString,
                )
        self.SimilarityChunksSearch = channel.unary_unary(
                '/artifact.artifact.v1alpha.ArtifactPublicService/SimilarityChunksSearch',
                request_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.SerializeToString,
                response_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.FromString,
                )


class ArtifactPublicServiceServicer(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def Liveness(self, request, context):
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKnowledgeBase(self, request, context):
        """Create a knowledge base
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKnowledgeBases(self, request, context):
        """Get all knowledge bases info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateKnowledgeBase(self, request, context):
        """Update a knowledge base info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKnowledgeBase(self, request, context):
        """Delete a knowledge base
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadKnowledgeBaseFile(self, request, context):
        """Create a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKnowledgeBaseFile(self, request, context):
        """Delete a file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProcessKnowledgeBaseFiles(self, request, context):
        """process file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKnowledgeBaseFiles(self, request, context):
        """list files
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListChunks(self, request, context):
        """List chunks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSourceFile(self, request, context):
        """Get source file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChunk(self, request, context):
        """Update chunk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimilarityChunksSearch(self, request, context):
        """Similarity chunks search
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ArtifactPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateKnowledgeBase': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKnowledgeBase,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseResponse.SerializeToString,
            ),
            'ListKnowledgeBases': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKnowledgeBases,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesResponse.SerializeToString,
            ),
            'UpdateKnowledgeBase': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateKnowledgeBase,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseResponse.SerializeToString,
            ),
            'DeleteKnowledgeBase': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKnowledgeBase,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseResponse.SerializeToString,
            ),
            'UploadKnowledgeBaseFile': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadKnowledgeBaseFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileResponse.SerializeToString,
            ),
            'DeleteKnowledgeBaseFile': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKnowledgeBaseFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileResponse.SerializeToString,
            ),
            'ProcessKnowledgeBaseFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessKnowledgeBaseFiles,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesResponse.SerializeToString,
            ),
            'ListKnowledgeBaseFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKnowledgeBaseFiles,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesResponse.SerializeToString,
            ),
            'ListChunks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListChunks,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.SerializeToString,
            ),
            'GetSourceFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSourceFile,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.SerializeToString,
            ),
            'UpdateChunk': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChunk,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.SerializeToString,
            ),
            'SimilarityChunksSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SimilarityChunksSearch,
                    request_deserializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.FromString,
                    response_serializer=artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'artifact.artifact.v1alpha.ArtifactPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ArtifactPublicService(object):
    """ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Liveness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/Readiness',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateKnowledgeBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/CreateKnowledgeBase',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.CreateKnowledgeBaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListKnowledgeBases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBases',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateKnowledgeBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateKnowledgeBase',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UpdateKnowledgeBaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKnowledgeBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBase',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadKnowledgeBaseFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UploadKnowledgeBaseFile',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.UploadKnowledgeBaseFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKnowledgeBaseFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/DeleteKnowledgeBaseFile',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.DeleteKnowledgeBaseFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProcessKnowledgeBaseFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ProcessKnowledgeBaseFiles',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ProcessKnowledgeBaseFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListKnowledgeBaseFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListKnowledgeBaseFiles',
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2.ListKnowledgeBaseFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListChunks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/ListChunks',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.ListChunksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSourceFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/GetSourceFile',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.GetSourceFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateChunk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/UpdateChunk',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.UpdateChunkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimilarityChunksSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/artifact.artifact.v1alpha.ArtifactPublicService/SimilarityChunksSearch',
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchRequest.SerializeToString,
            artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2.SimilarityChunksSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
